==> clean_android_design-0.0.169.tar.gz: lib/src/fields/default_field_widget.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:clean_android_design/src/settings/clean_android_design_style.dart';
import 'package:clean_android_design/src/utils/item_section_widget.dart';
import 'package:flutter/material.dart';

class DefaultFieldWidget extends StatelessWidget implements IListItem {
  final Text title;
  final Widget child;
  final bool isFirst;
  final bool isLast;
  final bool separationLine;
  final EdgeInsets childPadding;
  final HighlightController highlightController;

  const DefaultFieldWidget({
    Key key,
    this.title,
    this.child,
    this.isFirst = false,
    this.isLast = false,
    this.separationLine = true,
    this.childPadding,
    this.highlightController,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (highlightController == null)
      return _buildMainWidget(context, Colors.white);
    else
      return HighlightBuilder(
        controller: highlightController,
        builder: _buildMainWidget,
        defaultColor: Colors.white,
      );
  }

  Widget _buildMainWidget(BuildContext context, Color color) {
    var borderRadius = BorderRadius.only(
        bottomLeft: isLast ? Radius.circular(30) : Radius.zero,
        bottomRight: isLast ? Radius.circular(30) : Radius.zero,
        topLeft: isFirst ? Radius.circular(30) : Radius.zero,
        topRight: isFirst ? Radius.circular(30) : Radius.zero);

    return Container(
      width: MediaQuery.of(context).size.width,
      decoration: BoxDecoration(
        borderRadius: borderRadius,
        color: color,
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          title != null
              ? Padding(
                  padding: const EdgeInsets.only(
                      left: 30, right: 30, bottom: 3, top: 13),
                  child: DefaultTextStyle(
                      style: TextStyles.textStyleSize(14), child: title),
                )
              : Container(),
          Padding(
            padding: childPadding ??
                const EdgeInsets.only(left: 30, right: 30, bottom: 13, top: 6),
            child: child,
          ),
          !isLast && separationLine
              ? Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 30),
                  child: Divider(
                    color: CleanAndroidDesignDefaultColors.defaultColorLight,
                    height: 1.1,
                    thickness: 1.1,
                  ),
                )
              : Container()
        ],
      ),
    );
  }

  IListItem copyWithPosition({bool isFirst, bool isLast}) {
    return DefaultFieldWidget(
      child: this.child,
      key: this.key,
      title: this.title,
      separationLine: this.separationLine,
      childPadding: this.childPadding,
      highlightController: this.highlightController,
      isFirst: isFirst ?? this.isFirst,
      isLast: isLast ?? this.isLast,
    );
  }
}

==> clean_android_design-0.1.0.tar.gz: lib/src/fields/default_field_widget.dart <==
import 'package:clean_android_design/clean_android_design.dart';
import 'package:clean_android_design/src/settings/clean_android_design_style.dart';
import 'package:clean_android_design/src/utils/item_section_widget.dart';
import 'package:flutter/material.dart';

class DefaultFieldWidget extends StatelessWidget implements IListItem {
  final Text? title;
  final Widget? child;
  final bool? isFirst;
  final bool? isLast;
  final bool separationLine;
  final EdgeInsets? childPadding;
  final HighlightController? highlightController;

  const DefaultFieldWidget({
    Key? key,
    this.title,
    this.child,
    this.isFirst = false,
    this.isLast = false,
    this.separationLine = true,
    this.childPadding,
    this.highlightController,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (highlightController == null)
      return _buildMainWidget(context, Colors.white);
    else
      return HighlightBuilder(
        controller: highlightController,
        builder: _buildMainWidget,
        defaultColor: Colors.white,
      );
  }

  Widget _buildMainWidget(BuildContext context, Color color) {
    var borderRadius = BorderRadius.only(
        bottomLeft: isLast! ? Radius.circular(30) : Radius.zero,
        bottomRight: isLast! ? Radius.circular(30) : Radius.zero,
        topLeft: isFirst! ? Radius.circular(30) : Radius.zero,
        topRight: isFirst! ? Radius.circular(30) : Radius.zero);

    return Container(
      width: MediaQuery.of(context).size.width,
      decoration: BoxDecoration(
        borderRadius: borderRadius,
        color: color,
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          title != null
              ? Padding(
                  padding: const EdgeInsets.only(
                      left: 30, right: 30, bottom: 3, top: 13),
                  child: DefaultTextStyle(
                      style: TextStyles.textStyleSize(14), child: title!),
                )
              : Container(),
          Padding(
            padding: childPadding ??
                const EdgeInsets.only(left: 30, right: 30, bottom: 13, top: 6),
            child: child,
          ),
          !isLast! && separationLine
              ? Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 30),
                  child: Divider(
                    color: CleanAndroidDesignDefaultColors.defaultColorLight,
                    height: 1.1,
                    thickness: 1.1,
                  ),
                )
              : Container()
        ],
      ),
    );
  }

  IListItem copyWithPosition({bool? isFirst, bool? isLast}) {
    return DefaultFieldWidget(
      child: this.child,
      key: this.key,
      title: this.title,
      separationLine: this.separationLine,
      childPadding: this.childPadding,
      highlightController: this.highlightController,
      isFirst: isFirst ?? this.isFirst,
      isLast: isLast ?? this.isLast,
    );
  }
}
